/*
 *  Copyright 2005 Georgetown University
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package edu.georgetown.middleware.shibboleth.idp.ha.nameIdentifier;

import java.security.Principal;

import org.w3c.dom.Element;

import edu.internet2.middleware.shibboleth.common.IdentityProvider;
import edu.internet2.middleware.shibboleth.common.NameIdentifierMappingException;
import edu.internet2.middleware.shibboleth.common.ServiceProvider;

/**
 * Handle generators are used to generate handles for users.  
 * 
 * Generators 
 * MUST be thread safe as only a single instance will be created per IdP 
 * instance.  The {@link #configure(Element)} method will be called once
 * before the generator is used, initialization should be done at this time.
 * 
 * @author Chad La Joie
 */
public interface HandleGenerator {

    /**
     * Initializes and configures the generator.
     * 
     * @param config the <code>NameMapping</code> configuration element from the IdP configuration file
     * 
     * @throws NameIdentifierMappingException thrown if the generator can not be configured
     */
    public void configure(Element config) throws NameIdentifierMappingException;
    
    /**
     * Generates a handle for a given principal
     * 
     * @param principal the principal
     * @param sProv the service provider the principal is accessing
     * @param idProv information about the IdP instance
     * 
     * @return the handle
     * 
     * @throws NameIdentifierMappingException thrown if a handle can not be generated
     */
    public String generateHandle(Principal principal, ServiceProvider sProv, IdentityProvider idProv)
    throws NameIdentifierMappingException;
}
