/*
 *  Copyright 2005 Georgetown University
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */

package edu.georgetown.middleware.shibboleth.idp.ha.nameIdentifier;

import java.security.Principal;

import org.opensaml.SAMLConfig;
import org.opensaml.SAMLException;
import org.w3c.dom.Element;

import edu.internet2.middleware.shibboleth.common.IdentityProvider;
import edu.internet2.middleware.shibboleth.common.NameIdentifierMappingException;
import edu.internet2.middleware.shibboleth.common.ServiceProvider;

/**
 * A handle generator that simply returns a random string of characters, 
 * generated by the OpenSAML default ID provider, for the handle.
 * 
 * @author Chad La Joie
 */
public class OpenSAMLDefaultIDHandleGenerator implements HandleGenerator {

    /** SAML config instance where the default provider ID is pulled from */
    private SAMLConfig config = SAMLConfig.instance();
    
    /**
     * Initializes and configures the generator.
     * 
     * @param config the <code>NameMapping</code> configuration element from the IdP configuration file
     * 
     * @throws NameIdentifierMappingException thrown if the generator can not be configured
     */
    public void configure(Element config) throws NameIdentifierMappingException{
        //Does nothing
    }
    
    /**
     * Generates a handle for a given principal.  This handle contains nothing more than a 
     * random string of characters.
     * 
     * @param principal the principal
     * @param sProv the service provider the principal is accessing
     * @param idProv information about the IdP instance
     * 
     * @return the handle
     * 
     * @throws NameIdentifierMappingException thrown if a handle can not be generated
     */
    public String generateHandle(Principal principal, ServiceProvider sProv, IdentityProvider idProv)
    throws NameIdentifierMappingException{
        try {
            return config.getDefaultIDProvider().getIdentifier();
        }catch(SAMLException e) {
            throw new NameIdentifierMappingException("Unable to generate handle: " + e);
        }
    }
}
